[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,65 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/stream/interfaces/hashtable_linearprobing.cuh>
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
// Insert the key/values in kvs into the hashtable
|
||||
__global__ void gpu_hashtable_insert_kernel(hashtable h, const reserved::KeyValue* kvs, unsigned int numkvs)
|
||||
{
|
||||
unsigned int threadid = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
if (threadid < numkvs)
|
||||
{
|
||||
h.insert(kvs[threadid]);
|
||||
}
|
||||
}
|
||||
|
||||
void gpu_hashtable_insert(hashtable d_h, const reserved::KeyValue* device_kvs, unsigned int num_kvs, cudaStream_t stream)
|
||||
{
|
||||
// Have CUDA calculate the thread block size
|
||||
const auto occ_res = reserved::compute_occupancy(gpu_hashtable_insert_kernel);
|
||||
int threadblocksize = occ_res.block_size;
|
||||
int gridsize = ((uint32_t) num_kvs + threadblocksize - 1) / threadblocksize;
|
||||
|
||||
// Insert all the keys into the hash table
|
||||
gpu_hashtable_insert_kernel<<<gridsize, threadblocksize, 0, stream>>>(d_h, device_kvs, (uint32_t) num_kvs);
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
stream_ctx ctx;
|
||||
|
||||
// This constructor automatically initializes an empty hashtable on the host
|
||||
hashtable h;
|
||||
auto lh = ctx.logical_data(h);
|
||||
|
||||
// Create an array of values on the host
|
||||
reserved::KeyValue kvs_array[16];
|
||||
for (uint32_t i = 0; i < 16; i++)
|
||||
{
|
||||
kvs_array[i].key = i * 10;
|
||||
kvs_array[i].value = 17 + i * 14;
|
||||
}
|
||||
auto h_kvs_array = ctx.logical_data(make_slice(&kvs_array[0], 16));
|
||||
|
||||
ctx.task(lh.rw(), h_kvs_array.read())->*[](auto stream, auto h, auto a) {
|
||||
gpu_hashtable_insert(h, a.data_handle(), static_cast<uint32_t>(a.extent(0)), stream);
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
// Thanks to the write-back mechanism on lh, h has been updated
|
||||
for (size_t i = 0; i < 16; i++)
|
||||
{
|
||||
assert(h.get(i * 10) == 17 + i * 14);
|
||||
}
|
||||
}
|
||||
Reference in New Issue
Block a user